#!/bin/bash

# Copyright (c) 2005 Chris Reuter. all rights reserved.
#
# This software may be freely redistributed under the terms of the GNU
# public license.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#
# Wrapper script for Quest For Pants.  This sets everything up and
# starts Squeak on the game image.
#
# Requires Bash.

#
# You may need to set these to suit your system
#

# Program to unzip the initial game image.
BZIPCAT="bunzip2 -c"

# The base installation directory.
INSTDIR=/usr/local/games/lib/qfp

# The name of the Squeak VM we're going to use.
QFP_SQUEAK=$INSTDIR/vm/squeak

# Extra flags to pass to the Squeak VM.
SQUEAK_FLAGS=

# The name of the initial image
GAMEIMG=$INSTDIR/game.image.bz2

# The directory into which the player's save file goes.
PLAYDIR=~/.qfpdir

#--- No user-servicable parts beyond this point ---

# Special case: if this was called by the "play-now.sh" script, we
# need to readjust all of the paths.
if [ "$1" = "--play-now" ]; then
	# We know that the pwd is the untarred archive, so everything can
	# be relative to here:
	INSTDIR=`pwd`
	QFP_SQUEAK=`pwd`/unix/squeak
	GAMEIMG=`pwd`/image/game.image.bz2
fi


# The name of the save file.  It's long so that the squeak title bar
# will be somewhat meaningful.  Clever, eh?
save_file_name="Quest For Pants.image"

timestamp=time.stamp

# Function to print a message and die.
function die () {
	echo $*
	exit 1;
}


# If there's a Squeak executable in this directory, we assume that the
# user is trying to run the program from the install directory.
if [[ -x squeak ]]; then
	QFP_SQUEAK=`pwd`/squeak
	GAMEIMG=`pwd`/image/game.image.bz2
fi

# If the game is uncompressed, handle that as well.  In this case, we
# just replace bzip2 -c with ordinary cat.
if [[ ! -f $GAMEIMG ]] && [[ -f ${GAMEIMG%.bz2} ]]; then
	BZIPCAT=cat
fi


# First, see if we need to create the PLAYDIR
if [[ ! -d "$PLAYDIR" ]] ; then
	mkdir $PLAYDIR || die "Could not create $PLAYDIR"
fi

# Now, CD to the PLAYDIR
cd $PLAYDIR || die "Could not chdir to $PLAYDIR"

# If there's no saved game here, we start a new one by unzipping the
# stock image.
if [[ ! -f "$save_file_name" ]] ; then
	echo "Getting base image."
	$BZIPCAT $GAMEIMG > "$save_file_name"
fi


# # Create a timestamp file.
# touch $timestamp

# And run the game.
exec $QFP_SQUEAK $SQUEAK_FLAGS "$save_file_name"


# We no longer need this bit, since the Squeak image now
# self-destructs at the game's end anyway, but I'm leaving it in for now
# as a reference.


# # Okay, now the game has finished.  There are two possibilities: 
# # either the player has saved or the game has ended.  In the latter
# # case, we need to delete the existing save file.  The way we determine 

# # what happened is by comparing the game to the timestamp file.  If
# # the save file is newer, it means that the game has been saved since we
# # last touched the timestamp file so it's a save.  If not, it means the 
# # game ended and we need to erase it.

# if [[ $timestamp -nt "$save_file_name" ]]; then
# 	echo "GAME OVER"
# 	rm "$save_file_name"
# fi






